﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Data;
using Spire.DataExport.TXT;


namespace PhenoReports
{
    static class ExportManager
    {
        /// <summary>
        /// Exporta el dataTable en el fichero xls indicado
        /// (máximo 65535 filas y 256 columnas)
        /// </summary>
        /// <param name="tabla">DataTable a exportar</param>
        /// <param name="fichero">Fichero con extension xls</param>
        public static void exportToExcel(DataTable tabla,string fichero) 
        {
            Spire.DataExport.XLS.CellExport cellExport = new Spire.DataExport.XLS.CellExport();
            Spire.DataExport.XLS.WorkSheet worksheet1 = new Spire.DataExport.XLS.WorkSheet();
            cellExport.AutoFitColWidth = true;
            cellExport.DataFormats.CultureName = "es-es";
            cellExport.DataFormats.Currency = "?#.###.##0,00";
            cellExport.DataFormats.DateTime = "dd-MM-yyyy HH:mm";
            cellExport.DataFormats.Float = "#.###.##0,00";
            cellExport.DataFormats.Integer = "#.###.##0";
            cellExport.DataFormats.Time = "HH:mm";
            cellExport.SheetOptions.AggregateFormat.Font.Name = "Arial";
            cellExport.SheetOptions.CustomDataFormat.Font.Name = "Arial";
            cellExport.SheetOptions.DefaultFont.Name = "Arial";
            cellExport.SheetOptions.FooterFormat.Font.Name = "Arial";
            cellExport.SheetOptions.HeaderFormat.Font.Name = "Arial";
            cellExport.SheetOptions.HyperlinkFormat.Font.Color = Spire.DataExport.XLS.CellColor.Blue;
            cellExport.SheetOptions.HyperlinkFormat.Font.Name = "Arial";
            cellExport.SheetOptions.HyperlinkFormat.Font.Underline = Spire.DataExport.XLS.XlsFontUnderline.Single;
            cellExport.SheetOptions.NoteFormat.Alignment.Horizontal = Spire.DataExport.XLS.HorizontalAlignment.Left;
            cellExport.SheetOptions.NoteFormat.Alignment.Vertical = Spire.DataExport.XLS.VerticalAlignment.Top;
            cellExport.SheetOptions.NoteFormat.Font.Bold = true;
            cellExport.SheetOptions.NoteFormat.Font.Name = "Tahoma";
            cellExport.SheetOptions.NoteFormat.Font.Size = 8F;
            cellExport.SheetOptions.TitlesFormat.Font.Bold = true;
            cellExport.SheetOptions.TitlesFormat.Font.Name = "Arial";
            worksheet1.DataSource = Spire.DataExport.Common.ExportSource.DataTable;
            worksheet1.DataTable = tabla;
            worksheet1.SheetName = tabla.TableName;
            worksheet1.StartDataCol = ((System.Byte)(0));
            cellExport.Sheets.Add(worksheet1);
            cellExport.ActionAfterExport = Spire.DataExport.Common.ActionType.OpenView;
            cellExport.SaveToFile(fichero); 
        }

        public static void exportToWord(DataTable tabla, string fichero)
        {
            Spire.DataExport.RTF.RTFExport RTFExport = new Spire.DataExport.RTF.RTFExport();

            RTFExport.DataFormats.CultureName = "es-es";
            RTFExport.DataFormats.Currency = "c";
            RTFExport.DataFormats.DateTime = "dd-MM-yyyy HH:mm";
            RTFExport.DataFormats.Float = "g";
            RTFExport.DataFormats.Integer = "g";
            RTFExport.DataFormats.Time = "HH:mm";            
            RTFExport.RTFOptions.DataStyle.Font = new System.Drawing.Font("Tahoma", 10F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.World);
            RTFExport.RTFOptions.FooterStyle.Font = new System.Drawing.Font("Tahoma", 10F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.World);
            RTFExport.RTFOptions.HeaderStyle.Font = new System.Drawing.Font("Tahoma", 10F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.World);
            RTFExport.RTFOptions.TitleStyle.Alignment = Spire.DataExport.RTF.RtfTextAlignment.Center;
            RTFExport.RTFOptions.TitleStyle.Font = new System.Drawing.Font("Tahoma", 10F, System.Drawing.FontStyle.Bold);
            RTFExport.DataSource = Spire.DataExport.Common.ExportSource.DataTable;
            RTFExport.DataTable = tabla;
            RTFExport.ActionAfterExport = Spire.DataExport.Common.ActionType.OpenView;
            RTFExport.FileName = fichero;
            RTFExport.SaveToFile();
        }
        /// <summary>
        /// Exporta el dataTable al pdf expecificado
        /// </summary>
        /// <param name="tabla">Datatable con datos a exportar</param>
        /// <param name="fichero">Nombre de fichero a generar</param>
        public static void exportToPDF(DataTable tabla, string fichero)
        {
            Spire.DataExport.PDF.PDFExport PDFExport = new Spire.DataExport.PDF.PDFExport();
            PDFExport.DataSource = Spire.DataExport.Common.ExportSource.DataTable;
            PDFExport.Titles = new Spire.DataExport.Collections.StringListCollection();
            PDFExport.Titles.Add("Pheno Reports " + DateTime.Now.ToShortDateString());
            PDFExport.DataTable = tabla;
            PDFExport.ActionAfterExport = Spire.DataExport.Common.ActionType.OpenView;
            PDFExport.SaveToFile(fichero);
        }
        /// <summary>
        /// Exporta el datatable a un fichero csv. Se puede indicar si se desea mostrar el resultado para deshabilitarlo
        /// en caso de ser utilizado como origen de datos en la combinacion de correspondencia de word
        /// </summary>
        /// <param name="tabla">Datatable con datos a exportar</param>
        /// <param name="fichero">Nombre de fichero a generar</param>
        /// <param name="showResult">Mostrar (o no) resultados</param>
        public static void exportToCSV(DataTable tabla, string fichero,bool showResult = true)
        {
            TXTExport txtExport1 = new TXTExport();
            if (showResult == true)
            {
                txtExport1.ActionAfterExport = Spire.DataExport.Common.ActionType.OpenView;
            }
            else { txtExport1.ActionAfterExport = Spire.DataExport.Common.ActionType.None; }
            txtExport1.DataFormats.CultureName = "es-es";
            txtExport1.DataFormats.Currency = "€";
            txtExport1.DataFormats.DateTime = "dd-MM-yyyy HH:mm";
            txtExport1.DataFormats.Float = "g";
            txtExport1.DataFormats.Integer = "g";
            txtExport1.DataFormats.Time = "HH:mm";
            txtExport1.DataEncoding = Spire.DataExport.Common.EncodingType.ASCII;
            txtExport1.DataSource = Spire.DataExport.Common.ExportSource.DataTable;
            txtExport1.DataTable = tabla;
            txtExport1.ExportType = TextExportType.CSV;
            txtExport1.FileName = fichero;
            txtExport1.SaveToFile();
        }

    }
}
