﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.IO;

using MessagingToolkit.QRCode.Codec;
using MessagingToolkit.QRCode.Codec.Data;
using MessagingToolkit.QRCode.Helper;
using System.Windows.Controls;
using Word = Microsoft.Office.Interop.Word;
using System.ComponentModel;

namespace PhenoReports
{
    /// <summary>
    /// Clase que implementa la funcionalidad de un código QR
    /// </summary>
    public  class QRCodeManager
    {
        private System.Drawing.Image image;
        //Imagen que representa el codigo QR que será enviado a MS Word
        private BitmapSource bitmapSource;

        public BitmapSource BitmapSource
        {
            get { return bitmapSource; }
            set { bitmapSource = value; }
        } 

        public  QRCodeManager(string quickResponse) 
        {
            QRCodeEncoder encoder = new QRCodeEncoder();
            encoder.QRCodeEncodeMode = QRCodeEncoder.ENCODE_MODE.BYTE;
            encoder.QRCodeErrorCorrect = QRCodeEncoder.ERROR_CORRECTION.M;
            encoder.CharacterSet = "UTF-8";
            image = encoder.Encode(quickResponse);
            bitmapSource = ImageHelper.ToBitmapSource(image);           
        
        }


        /// <summary>
        /// Método que abre o crea un fichero word e inserta la imagen QR en 
        /// un marcador llamado IMAGEN_QR
        /// </summary>        
        /// <param name="fichWord">Fichero Word en el que se insertará el código QR</param>
        public void generaQRWord(string fichWord) 
        {
            //Genera Txt que será el origen de datos para la combinación de correspondencia con el mismo nombre que el fichero word
            //que presentará y fusionará los resultados
            try
            {

                string listSeparator = System.Globalization.CultureInfo.CurrentCulture.TextInfo.ListSeparator;

                Word.Application wrdApp;
                Word._Document wrdDoc;
                wrdApp = new Word.Application();
                Object oMissing = System.Reflection.Missing.Value;
                Object oFalse = false;
                Object oName = fichWord;
                //Comprueva si el word de plantilla existe.
                bool nuevoDoc = !System.IO.File.Exists((string)oName);
                if (nuevoDoc)
                {
                    MessageBox.Show("Documento no existente, se creará un documento vacío enlazado a los datos.", "", MessageBoxButton.OK, MessageBoxImage.Information);

                    wrdDoc = wrdApp.Documents.Add(ref oMissing, ref oMissing, ref oMissing, true);
                }
                else
                {
                    wrdDoc = wrdApp.Documents.Open(ref oName, ref oMissing, ref oMissing, ref oMissing, ref oMissing, ref oMissing,
                        ref oMissing, ref oMissing, ref oMissing, ref oMissing, ref oMissing, true, ref oMissing, ref oMissing, ref oMissing, ref oMissing);
                }

                wrdApp.Visible = true;
                if(!wrdDoc.Bookmarks.Exists("IMAGEN_QR")){
                wrdDoc.Bookmarks.Add("IMAGEN_QR", ref oMissing);
                }
                Microsoft.Office.Interop.Word.Range range = wrdDoc.Bookmarks["IMAGEN_QR"].Range;
                range.InsertAfter(" ");
                wrdApp.Selection.TypeParagraph();
                Clipboard.SetImage(bitmapSource);
                range.Paste();
                wrdDoc.Bookmarks.Add("IMAGEN_QR",range);
                if (nuevoDoc)
                {
                    wrdDoc.SaveAs(oName, ref oMissing, ref oMissing, ref oMissing, ref oMissing, ref oMissing, ref oMissing, ref oMissing, ref oMissing, ref oMissing,
                        ref oMissing, ref oMissing, ref oMissing, ref oMissing, ref oMissing, ref oMissing);
                }
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error en la creacion del fichero");
            }
        }
    }
}
