﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Collections.ObjectModel;
using System.Data.OleDb;
using System.Configuration;
using System.Data;
using System.Data.Objects;

namespace PhenoReports
{

    public static  class QueryUtils 
    {

        /// <summary>
        /// Funcion que ejecuta una consulta SQL en la conexión de Hematos y devuelve un DataTable con 
        /// las filas resultantes
        /// </summary>
        /// <param name="tableName">"nombre del dataTable</param>
        /// <param name="sqlQuery">Consulta a ejecutar</param>
        /// <returns></returns>
        public static DataTable fillDatatableWithSql(string tableName, string sqlQuery)
        {
            //Conexion con base datos Hematos             
            OleDbConnection oConn;
            oConn = new OleDbConnection(ConfigurationManager.ConnectionStrings["PhenoReports.Properties.Settings.hemoSQLConnectionString"].ToString());
            oConn.Open();

            OleDbCommand sqlCmd = new OleDbCommand(sqlQuery, oConn);
            OleDbDataReader dReader = sqlCmd.ExecuteReader();
            DataTable myTable = new DataTable(tableName);
            myTable.Load(dReader);
            dReader.Close();
            oConn.Close();

            return myTable;
        }
    
    }


    /// <summary>
    /// Clase que modela un parametro en una consulta sql
    /// 
    /// </summary>
    public class parametro 
    {
        public string param { get; set; }
        public string valor { get; set; }
        /// <summary>
        /// Construye un objeto parametro 
        /// 
        /// </summary>
        /// <param name="par">Nombre del parametro (&Parametro)</param>
        /// <param name="val">Valor</param>
        public parametro(string par, string val) { 
            param = par; valor = val; 
        }
        
    }
    

    /// <summary>
    /// Clase que modela una consulta SQL de la que extraecoleccion de parámetros a partir de una consulta SQL
    /// </summary>
    public class SQLQueryParametersCollection
    {
        /// <summary>
        /// Coleccion de parametros
        /// </summary>
        private ObservableCollection<parametro> parametros;

        public ObservableCollection<parametro> Parametros
        {
            get { return parametros; }
            set { parametros = value; }
        }

        private string sqlQuery;
        /// <summary>
        /// Cadena que contiene instruccion SQL
        /// </summary>
        public string SqlQuery
        {
            get { return sqlQuery; }
            set { sqlQuery = value; }
        }

       

        public void setSQLQueryParametersCollection(string s)
        {
            int index1 = 0, index2 = 0;
            sqlQuery = s;

            parametros = new ObservableCollection<parametro>();

            while ((s.IndexOf('&', index1) > index1) && index1 <= s.Length)
            {
                index1 = s.IndexOf('&', index1);
                index2 = s.IndexOf(' ', index1);
                parametros.Add(new parametro(s.Substring(index1, index2 - index1), ""));
                index1 = index2;
            }

        }

          
        /// <summary>
        /// Clase que ejecuta una consulta sql nativa en Entity Frameword
        /// </summary>
        /// <typeparam name="T"></typeparam>
        /// <param name="sql"></param>
        
        /// <returns></returns>
         public IEnumerable<T> selectParameters<T>(string sql) 
         {
             modelHemo.hemoEntities hemoEntity = new modelHemo.hemoEntities();
             ObjectResult<T> results = hemoEntity.ExecuteStoreQuery<T>(sql);
             return results;
         }

    }

}
